@@ -357,22 +357,13 @@ sub run {
     # correct dpkg (and optionally debhelper) versions
     if ($profiles_used) {
         my $build_all = $info->relation('build-depends-all');
-        my $build_conflicts_all = $info->relation('build-conflicts-all');
         tag 'restriction-formula-without-versioned-dpkg-dev-dependency'
           unless ($build_all->implies('dpkg-dev (>= 1.17.14~)'));
-        tag 'restriction-formula-with-versioned-dpkg-dev-conflict'
-          if ($build_conflicts_all->implies_inverse('dpkg-dev (<< 1.17.14)'));
         # if the package uses debhelper then it must require and not
         # conflict with version >= 9.20141010
         if ($build_all->implies('debhelper')) {
             tag 'restriction-formula-with-debhelper-without-debhelper-version'
               unless ($build_all->implies('debhelper (>= 9.20141010~)'));
-            #<<< no tidy, tag name too long
-            tag 'restriction-formula-with-debhelper-with-conflicting-version'
-            #>>>
-              if (
-                $build_conflicts_all->implies_inverse(
-                    'debhelper (<< 9.20141010)'));
         }
     }
 
