@@ -65,8 +65,7 @@ sub run {
     my $dhcompatvalue;
     my $inclcdbs = 0;
 
-    my $bdepends_noarch;
-    my $bdepends;
+    my ($bdepends_noarch, $bdepends, %build_systems);
     my $seen_dh = 0;
     my $seen_python_helper = 0;
     my $seen_python3_helper = 0;
@@ -89,33 +88,21 @@ sub run {
 
         if (m/^\s+-?(dh_\S+)/) {
             my $dhcommand = $1;
+            $build_systems{'debhelper'} = 1
+              if not exists($build_systems{'dh'});
 
-            if ($dhcommand eq 'dh_undocumented') {
-                tag 'dh_undocumented-is-obsolete', "line $.";
-            }
-            if ($dhcommand eq 'dh_pysupport') {
-                tag 'dh_pysupport-is-obsolete', "line $.";
-                $seen_python_helper = 1;
-            }
             if ($dhcommand eq 'dh_installmanpages') {
                 tag 'dh_installmanpages-is-obsolete', "line $.";
             }
             if ($dhcommand eq 'dh_python3') {
                 $seen_python3_helper = 1;
             }
-            if ($dhcommand =~ m,^dh_(?:pysupport$|python(?:2$|\$.*)),) {
+            if ($dhcommand =~ m,^dh_python(?:2$|\$.*),) {
                 $seen_python_helper = 1;
             }
 
-            # Don't warn about recently deprecated commands in code that may be
-            # optional.  It may be there only for backports.
-            unless ($maybe_skipping) {
-                if ($dhcommand eq 'dh_desktop') {
-                    tag 'dh_desktop-is-deprecated', "line $.";
-                }
-                if ($dhcommand eq 'dh_clean' and m/\s+\-k(?:\s+.*)?$/s) {
-                    $seendhcleank = 1;
-                }
+            if ($dhcommand eq 'dh_clean' and m/\s+\-k(?:\s+.*)?$/s) {
+                $seendhcleank = 1;
             }
 
             # if command is passed -n, it does not modify the scripts
@@ -138,6 +125,8 @@ sub run {
             $seencommand = 1;
             $needbuilddepends = 1;
         } elsif (m,^\s+dh\s+,) {
+            $build_systems{'dh'} = 1;
+            delete($build_systems{'debhelper'});
             $seen_dh = 1;
             $seencommand = 1;
             $needbuilddepends = 1;
@@ -151,7 +140,7 @@ sub run {
                     if (defined $depends) {
                         $missingbdeps_addons{$depends} = $addon;
                     }
-                    if ($addon =~ m,python(?:2|_central|_support)$,) {
+                    if ($addon eq 'python2') {
                         $seen_python_helper = 1;
                     } elsif ($addon eq 'python3') {
                         $seen_python3_helper = 1;
@@ -166,10 +155,9 @@ sub run {
                 $seen_python_helper = 1;
                 $seen_python3_helper = 1;
             }
-            if ($seen_python_helper == 0) {
-                $seen_python_helper = -1; # maybe; we'll check that later
-            }
         } elsif (m,^include\s+/usr/share/cdbs/1/rules/debhelper.mk,) {
+            $build_systems{'cdbs-with-debhelper.mk'} = 1;
+            delete($build_systems{'cdbs-without-debhelper.mk'});
             $seencommand = 1;
             $needbuilddepends = 1;
             $needtomodifyscripts = 1;
@@ -192,6 +180,8 @@ sub run {
         } elsif (m,^include\s+/usr/share/cdbs/,
             or m,^include\s+/usr/share/R/debian/r-cran.mk,o) {
             $inclcdbs = 1;
+            $build_systems{'cdbs-without-debhelper.mk'} = 1
+              if not exists($build_systems{'cdbs-with-debhelper.mk'});
         }
     }
     close($rules_fd);
@@ -202,6 +192,13 @@ sub run {
         tag 'unused-build-dependency-on-cdbs' if ($bdepends->implies('cdbs'));
     }
 
+    if (%build_systems) {
+        my @systems = sort(keys(%build_systems));
+        tag 'debian-build-system', join(', ', @systems);
+    } else {
+        tag 'debian-build-system', 'other';
+    }
+
     return unless $seencommand;
 
     my @pkgs = $info->binaries;
@@ -398,10 +395,7 @@ sub run {
         tag $tagname, $level;
     }
 
-    if ($seen_python_helper == -1 and $level >= 9) {
-        $seen_python_helper = 0;
-    }
-    if ($seen_dh and $seen_python_helper != 1) {
+    if ($seen_dh and not $seen_python_helper) {
         my %python_depends;
         for my $binpkg (@pkgs) {
             if ($info->binary_relation($binpkg, 'all')
@@ -410,17 +404,11 @@ sub run {
             }
         }
         if (%python_depends) {
-            if ($seen_python_helper == -1) {
-                $seen_python_helper
-                  = $bdepends_noarch->implies('python-support');
-            }
-            if (not $seen_python_helper) {
-                tag 'python-depends-but-no-python-helper',
-                  sort(keys %python_depends);
-            }
+            tag 'python-depends-but-no-python-helper',
+              sort(keys %python_depends);
         }
     }
-    if ($seen_dh and $seen_python3_helper != 1) {
+    if ($seen_dh and not $seen_python3_helper) {
         my %python3_depends;
         for my $binpkg (@pkgs) {
             if ($info->binary_relation($binpkg, 'all')
@@ -428,7 +416,7 @@ sub run {
                 $python3_depends{$binpkg} = 1;
             }
         }
-        if (%python3_depends and not $seen_python3_helper) {
+        if (%python3_depends) {
             tag 'python3-depends-but-no-python3-helper',
               sort(keys %python3_depends);
         }
@@ -498,7 +486,7 @@ sub _check_dh_exec {
                     $dhe_useless = 1;
                 }
             }
-            if ($dhe_useless) {
+            if ($dhe_useless && $path =~ /debian\/.*(install|manpages)/) {
                 my $form = $_;
                 chomp($form);
                 $form = "\"$form\"";
