@@ -81,11 +81,11 @@ our %known_tkxs = map { $_ => 1 } ('tkx8.2', 'tkx8.3',);
 our %known_libpngs = map { $_ => 1 } ('libpng12-0', 'libpng2', 'libpng3',);
 
 our @known_java_pkg = map { qr/$_/ } (
-    'default-jre(?:-headless)?', 'default-jdk', # default java
-    'java\d*-runtime(?:-headless)?'
-    , # java-runtime and javaX-runtime alternatives (virtual)
-    '(openjdk-|sun-java)\d+-jre(?:-headless)?',
-    '(openjdk-|sun-java)\d+-jdk', # openjdk-X and sun-javaX
+    'default-j(?:re|dk)(?:-headless)?',
+    # java-runtime and javaX-runtime alternatives (virtual)
+    'java\d*-runtime(?:-headless)?',
+    # openjdk-X and sun-javaX
+    '(openjdk-|sun-java)\d+-j(?:re|dk)(?:-headless)?',
     'gcj-(?:\d+\.\d+-)?jre(?:-headless)?', 'gcj-(?:\d+\.\d+-)?jdk', # gcj
     'gij',
     'java-gcj-compat(?:-dev|-headless)?', # deprecated/transitional packages
@@ -128,12 +128,12 @@ my %VCS_EXTRACT = (
 my %VCS_CANONIFY = (
     browser => sub {
         $_[0] =~ s{https?://svn\.debian\.org/wsvn/}
-                  {http://anonscm.debian.org/viewvc/};
-        $_[0] =~ s{\Qhttp://git.debian.org/?p=\E}
-                  {https://anonscm.debian.org/cgit/};
-        $_[0] =~ s{\Qhttp://bzr.debian.org/loggerhead/\E}
-                  {http://anonscm.debian.org/loggerhead/};
-        if ($_[0] =~ m{\Qhttp://anonscm.debian.org/viewvc/\E}xsm) {
+                  {https://anonscm.debian.org/viewvc/};
+        $_[0] =~ s{https?\Q://git.debian.org/?p=\E}
+                  {https://anonscm.debian.org/git/};
+        $_[0] =~ s{https?\Q://bzr.debian.org/loggerhead/\E}
+                  {https://anonscm.debian.org/loggerhead/};
+        if ($_[0] =~ m{https?\Q://anonscm.debian.org/viewvc/\E}xsm) {
             if ($_[0] =~ s{\?(.*[;\&])?op=log(?:[;\&](.*))?\Z}{}xsm) {
                 my (@keep) = ($1, $2, $3);
                 my $final = join('', grep {defined} @keep);
@@ -152,25 +152,25 @@ my %VCS_CANONIFY = (
         $_[0] =~ s{\@cvs.alioth.debian.org:/cvs/}{\@anonscm.debian.org:/cvs/};
     },
     arch     => sub {
-        $_[0] =~ s{\Qhttp://arch.debian.org/arch/\E}
-                  {http://anonscm.debian.org/arch/};
+        $_[0] =~ s{https?\Q://arch.debian.org/arch/\E}
+                  {https://anonscm.debian.org/arch/};
     },
     bzr     => sub {
-        $_[0] =~ s{\Qhttp://bzr.debian.org/\E}
-                  {http://anonscm.debian.org/bzr/};
-        $_[0] =~ s{\Qhttp://anonscm.debian.org/bzr/bzr/\E}
-                  {http://anonscm.debian.org/bzr/};
+        $_[0] =~ s{https?\Q://bzr.debian.org/\E}
+                  {https://anonscm.debian.org/bzr/};
+        $_[0] =~ s{https?\Q://anonscm.debian.org/bzr/bzr/\E}
+                  {https://anonscm.debian.org/bzr/};
     },
     git     => sub {
         if (
             $_[0] =~ s{git://(?:git|anonscm)\.debian\.org/~}
-                      {git://anonscm.debian.org/users/}
+                      {https://anonscm.debian.org/git/users/}
           ) {
             $_[1] = 'vcs-git-uses-invalid-user-uri';
         }
-        $_[0] =~ s{\Qhttp://git.debian.org/\E}
+        $_[0] =~ s{https?\Q://git.debian.org/\E}
                   {https://anonscm.debian.org/git/};
-        $_[0] =~ s{\Qhttp://anonscm.debian.org/git/git/\E}
+        $_[0] =~ s{https?\Q://anonscm.debian.org/git/git/\E}
                   {https://anonscm.debian.org/git/};
         $_[0] =~ s{\Qgit://git.debian.org/\E}
                   {https://anonscm.debian.org/git/};
@@ -178,10 +178,10 @@ my %VCS_CANONIFY = (
                   {https://anonscm.debian.org/git/};
     },
     hg      => sub {
-        $_[0] =~ s{\Qhttp://hg.debian.org/\E}
-                  {http://anonscm.debian.org/hg/};
-        $_[0] =~ s{\Qhttp://anonscm.debian.org/hg/hg/\E}
-                  {http://anonscm.debian.org/hg/};
+        $_[0] =~ s{https?\Q://hg.debian.org/\E}
+                  {https://anonscm.debian.org/hg/};
+        $_[0] =~ s{https?\Q://anonscm.debian.org/hg/hg/\E}
+                  {https://anonscm.debian.org/hg/};
     },
     svn     => sub {
         $_[0] =~ s{\Qsvn://cvs.alioth.debian.org/\E}
@@ -219,7 +219,7 @@ my %VCS_VALID_URIS = (
 # dependencies for architecture-independent source packages.
 our $PYTHON_DEV = join(' | ',
     qw(python-dev python-all-dev python3-dev python3-all-dev),
-    map { "python$_-dev" } qw(2.7 3 3.2));
+    map { "python$_-dev" } qw(2.7 3 3.4 3.5));
 
 our $PERL_CORE_PROVIDES = Lintian::Data->new('fields/perl-provides', '\s+');
 our $OBSOLETE_PACKAGES
@@ -730,8 +730,10 @@ sub run {
                         $part_d_orig)
                       = @$part_d;
 
-                    tag 'versioned-provides', $part_d_orig
-                      if ($field eq 'provides' && $d_version->[0]);
+                    tag 'invalid-versioned-provides', $part_d_orig
+                      if ( $field eq 'provides'
+                        && $d_version->[0]
+                        && $d_version->[0] ne '=');
 
                     tag 'bad-provided-package-name', $d_pkg
                       if $d_pkg !~ /^[a-z0-9][-+\.a-z0-9]+$/;
@@ -946,15 +948,19 @@ sub run {
         tag 'build-depends-indep-without-arch-indep'
           if (defined $info->field('build-depends-indep')
             && $arch_indep_packages == 0);
+        tag 'build-depends-arch-without-arch-dependant-binary'
+          if (defined $info->field('build-depends-arch')
+            && $arch_dep_packages == 0);
 
         my $is_dep_field = sub {
-            any { $_ eq $_[0] } qw(build-depends build-depends-indep);
+            any { $_ eq $_[0] }
+            qw(build-depends build-depends-indep build-depends-arch);
         };
 
         my $restrictions_used = 0;
         my %depend;
         for my $field (
-            qw(build-depends build-depends-indep build-conflicts build-conflicts-indep)
+            qw(build-depends build-depends-indep build-depends-arch build-conflicts build-conflicts-indep build-conflicts-arch)
           ) {
             if (defined $info->field($field)) {
                 #Get data and clean it
@@ -1113,7 +1119,11 @@ sub run {
         }
 
         # Make sure build dependencies and conflicts are consistent.
-        for ($depend{'build-conflicts'}, $depend{'build-conflicts-indep'}) {
+        for (
+            $depend{'build-conflicts'},
+            $depend{'build-conflicts-indep'},
+            $depend{'build-conflicts-arch'}
+          ) {
             next unless $_;
             for my $conflict (split /\s*,\s*/, $_) {
                 if ($build_all->implies($conflict)) {
@@ -1127,23 +1137,13 @@ sub run {
         if ($restrictions_used) {
             my $build_conflicts_all = $info->relation('build-conflicts-all');
             tag 'restriction-formula-without-versioned-dpkg-dev-dependency'
-              unless ($build_all->implies('dpkg-dev (>= 1.17.14)'));
-            tag 'restriction-formula-with-versioned-dpkg-dev-conflict'
-              if (
-                $build_conflicts_all->implies_inverse('dpkg-dev (<< 1.17.14)')
-              );
+              unless ($build_all->implies('dpkg-dev (>= 1.17.14~)'));
             # if the package uses debhelper then it must require and not
             # conflict with version >= 9.20141010
             if ($build_all->implies('debhelper')) {
                 tag
 'restriction-formula-with-debhelper-without-debhelper-version'
-                  unless ($build_all->implies('debhelper (>= 9.20141010)'));
-                #<<< no tidy, tag name too long
-                tag 'restriction-formula-with-debhelper-with-conflicting-version'
-                #>>>
-                  if (
-                    $build_conflicts_all->implies_inverse(
-                        'debhelper (<< 9.20141010)'));
+                  unless ($build_all->implies('debhelper (>= 9.20141010~)'));
             }
         }
 
@@ -1291,7 +1291,8 @@ sub run {
                 if (any { $_ and /\s/} @parts) {
                     tag 'vcs-field-has-unexpected-spaces', "vcs-$vcs", $uri;
                 }
-                if ($parts[0] =~ m%^(?:git|http)://%) {
+                if (   $parts[0] =~ m%^(?:git|(?:nosmart\+)?http|svn)://%
+                    or $parts[0] =~ m%^(?:lp|:pserver):%) {
                     tag 'vcs-field-uses-insecure-uri', "vcs-$vcs", $uri;
                 }
             }
