@@ -23,7 +23,7 @@ use strict;
 use warnings;
 use autodie;
 
-use constant LINTIAN_COVERAGE => ($ENV{'LINTIAN_COVERAGE'}//0);
+use constant LINTIAN_COVERAGE => ($ENV{'LINTIAN_COVERAGE'}?1:0);
 
 use File::Basename;
 use List::MoreUtils qw(any none);
@@ -304,7 +304,7 @@ sub run {
                 }
                 # Check for spelling errors if the manpage is English
                 check_spelling($line, $ginfo->spelling_exceptions,
-                    $stag_emitter)
+                    $stag_emitter, 0)
                   if ($path =~ m,/man/man\d/,);
             }
         }
