@@ -29,7 +29,7 @@ use Lintian::Relation;
 use Carp qw(croak);
 use Parse::DebianChangelog;
 
-use Lintian::Util qw(fail open_gz parse_dpkg_control get_file_checksum);
+use Lintian::Util qw(fail open_gz parse_dpkg_control get_file_checksum strip);
 
 =head1 NAME
 
@@ -88,7 +88,7 @@ L<Lintian::Collect::Package> modules are also available.
 =item native
 
 Returns true if the binary package is native and false otherwise.
-Nativeness will be judged by its version number.
+Nativeness will be judged by the source version number.
 
 If the version number is absent, this will return false (as
 native packages are a lot rarer than non-native ones).
@@ -100,7 +100,13 @@ Needs-Info requirements for using I<native>: L<Same as field|Lintian::Collect/fi
 sub native {
     my ($self) = @_;
     return $self->{native} if exists $self->{native};
-    my $version = $self->field('version');
+    my $version;
+    my $source = $self->field('source');
+    if (defined $source && $source =~ m/\((.*)\)/) {
+        $version = $1;
+    } else {
+        $version = $self->field('version');
+    }
     if (defined $version) {
         $self->{native} = ($version !~ m/-/);
     } else {
@@ -369,19 +375,13 @@ sub objdump_info {
     local $_;
     my $fd = open_gz($objf);
     foreach my $pg (parse_dpkg_control($fd)) {
-        my %info = (
-            'PH' => {},
-            'SH' => {},
-            'ELF'    => 1,
-            'NOTES'  => [],
-            'NEEDED' => [],
-            'RPATH'  => {},
-            'SONAME' => [],
-            'TEXTREL' => 0,
-        );
-        $info{'ERRORS'} = lc($pg->{'broken'}//'no') eq 'yes' ? 1 : 0;
-        $info{'BAD-DYNAMIC-TABLE'}
-          = lc($pg->{'bad-dynamic-table'}//'no') eq 'yes' ? 1 : 0;
+        my %info;
+        if (lc($pg->{'broken'}//'no') eq 'yes') {
+            $info{'ERRORS'} = 1;
+        }
+        if (lc($pg->{'bad-dynamic-table'}//'no') eq 'yes') {
+            $info{'BAD-DYNAMIC-TABLE'} = 1;
+        }
         foreach my $symd (split m/\s*\n\s*/, $pg->{'dynamic-symbols'}//'') {
             next unless $symd;
             if ($symd =~ m/^\s*(\S+)\s+(?:(\S+)\s+)?(\S+)$/){
@@ -391,20 +391,24 @@ sub objdump_info {
                 push @{ $info{'SYMBOLS'} }, [$sec, $ver, $sym];
             }
         }
-        foreach my $data (split m/\s*\n\s*/, $pg->{'section-headers'}//'') {
-            next unless $data;
-            my (undef, $section) = split m/\s++/, $data;
-            $info{'SH'}->{$section}++;
+        foreach my $section (split m/\s*\n\s*/, $pg->{'section-headers'}//'') {
+            next unless $section;
+            # NB: helpers/coll/objdump-info-helper discards most
+            # sections.  If you are missing a section name for a
+            # check, please update helpers/coll/objdump-info-helper to
+            # retrain the section name you need.
+            strip($section);
+            $info{'SH'}{$section} = 1;
         }
         foreach my $data (split m/\s*\n\s*/, $pg->{'program-headers'}//'') {
             next unless $data;
             my ($header, @vals) = split m/\s++/, $data;
-            $info{'PH'}->{$header} = {};
             foreach my $extra (@vals) {
                 my ($opt, $val) = split m/=/, $extra;
-                $info{'PH'}->{$header}->{$opt} = $val;
                 if ($opt eq 'interp' and $header eq 'INTERP') {
                     $info{'INTERP'} = $val;
+                } else {
+                    $info{'PH'}{$header}{$opt} = $val;
                 }
             }
         }
@@ -415,7 +419,7 @@ sub objdump_info {
             if ($header eq 'RPATH') {
                 # RPATH is like PATH
                 foreach my $rpathcomponent (split(m/:/,$val)) {
-                    $info{$header}->{$rpathcomponent} = 1;
+                    $info{$header}{$rpathcomponent} = 1;
                 }
             } elsif ($header eq 'NEEDED' or $header eq 'SONAME') {
                 push @{ $info{$header} }, $val;
@@ -428,15 +432,10 @@ sub objdump_info {
             # object file in a static lib.
             my ($lib, $obj) = ($1, $2);
             my $libentry = $objdump_info{$lib};
-            $info{'ELF'} = 0;
             if (not defined $libentry) {
                 $libentry = {
                     'filename' => $lib,
                     'objects'  => [$obj],
-                    # static libs have no SONAMEs (and shared-libs
-                    # checks for it)
-                    'SONAME'   => [],
-                    'ELF'      => 0,
                 };
                 $objdump_info{$lib} = $libentry;
             } else {
@@ -498,8 +497,8 @@ a hash containing the following keys:
 A hash containing the contents of the JAR file manifest. For instance,
 to find the classpath of I<$file>, you could use:
 
- if (exists $info->java_info->{$file}->{'manifest'}) {
-     my $cp = $info->java_info->{$file}->{'manifest'}->{'Class-Path'};
+ if (exists $info->java_info->{$file}{'manifest'}) {
+     my $cp = $info->java_info->{$file}{'manifest'}{'Class-Path'};
      # ...
  }
 
@@ -545,16 +544,16 @@ sub java_info {
         next if m/^\s*$/o;
 
         if (m#^-- ERROR:\s*(\S.++)$#o) {
-            $java_info{$file}->{error} = $1;
+            $java_info{$file}{error} = $1;
         } elsif (m#^-- MANIFEST: (?:\./)?(?:.+)$#o) {
             # TODO: check $file == $1 ?
-            $java_info{$file}->{manifest} = {};
-            $manifest = $java_info{$file}->{manifest};
+            $java_info{$file}{manifest} = {};
+            $manifest = $java_info{$file}{manifest};
             $file_list = 0;
         } elsif (m#^-- (?:\./)?(.+)$#o) {
             $file = $1;
-            $java_info{$file}->{files} = {};
-            $file_list = $java_info{$file}->{files};
+            $java_info{$file}{files} = {};
+            $file_list = $java_info{$file}{files};
             $manifest = 0;
         } else {
             if ($manifest && m#^  (\S+):\s(.*)$#o) {
@@ -603,7 +602,7 @@ Needs-Info requirements for using I<relation>: L<Same as field|Lintian::Collect/
 sub relation {
     my ($self, $field) = @_;
     $field = lc $field;
-    return $self->{relation}->{$field} if exists $self->{relation}->{$field};
+    return $self->{relation}{$field} if exists $self->{relation}{$field};
 
     my %special = (
         all    => [qw(pre-depends depends recommends suggests)],
@@ -621,8 +620,8 @@ sub relation {
         my $value = $self->field($field);
         $result = Lintian::Relation->new($value);
     }
-    $self->{relation}->{$field} = $result;
-    return $self->{relation}->{$field};
+    $self->{relation}{$field} = $result;
+    return $self->{relation}{$field};
 }
 
 =item is_pkg_class ([TYPE])
@@ -708,7 +707,7 @@ Needs-Info requirements for using I<is_conffile>: L<Same as control_index_resolv
 sub is_conffile {
     my ($self, $file) = @_;
     if (exists $self->{'conffiles'}) {
-        return 1 if exists $self->{'conffiles'}->{$file};
+        return 1 if exists $self->{'conffiles'}{$file};
         return;
     }
     my $cf = $self->control_index_resolved_path('conffiles');
