@@ -23,6 +23,7 @@ use autodie;
 
 use Exporter qw(import);
 
+use Carp qw(croak);
 use Dpkg::Vendor;
 
 use Lintian::CollScript;
@@ -54,6 +55,7 @@ sub check_test_feature{
     # (e.g. tar) start in.  In particular, we do not want to inherit
     # some random "TAR_OPTIONS" or "GZIP" values.
     my %PRESERVE_ENV = map { $_ => 1 } qw(
+      DEBRELEASE_DEBS_DIR
       HOME
       LANG
       LC_ALL
@@ -132,7 +134,7 @@ sub load_collections {
 sub default_parallel {
     # check cpuinfo for the number of cores...
     my %opts = ('err' => '&1');
-    my $cpus = safe_qx('nproc');
+    my $cpus = safe_qx(\%opts, 'nproc');
     if ($? == 0 and $cpus =~ m/^\d+$/) {
         # Running up to twice the number of cores usually gets the most out
         # of the CPUs and disks but it might be too aggressive to be the
@@ -158,7 +160,7 @@ sub default_parallel {
     # Where the marked part(s) are optional values.  The numbers above
     # the example are the capture groups.
     my $TAG_REGEX
-      = qr/([EWIXOP]): (\S+)(?: (\S+)(?:$verarchre)?)?: (\S+)(?:\s+(.*))?/o;
+      = qr/([EWIXOPC]): (\S+)(?: (\S+)(?:$verarchre)?)?: (\S+)(?:\s+(.*))?/o;
 
     sub split_tag {
         my ($tag_input) = @_;
