@@ -42,7 +42,8 @@ BEGIN {
 our $GLOBAL;
 
 # Ordered lists of severities and certainties, used for display level parsing.
-our @SEVERITIES  = qw(pedantic wishlist minor normal important serious);
+our @SEVERITIES
+  = qw(classification pedantic wishlist minor normal important serious);
 our @CERTAINTIES = qw(wild-guess possible certain);
 
 =head1 NAME
@@ -146,6 +147,8 @@ sub new {
     my $self = {
         current           => undef,
         display_level     => {
+            classification =>
+              { 'wild-guess' => 0, possible => 0, certain => 0 },
             wishlist  => { 'wild-guess' => 0, possible => 0, certain => 0 },
             minor     => { 'wild-guess' => 0, possible => 0, certain => 1 },
             normal    => { 'wild-guess' => 0, possible => 1, certain => 1 },
@@ -539,7 +542,7 @@ sub file_overrides {
         #   parsing overrides is a bit ambiguous (see #699628)
         if (
             $override =~ m/\A (?:                   # start optional part
-                  (\Q$info->{package}\E)?           # optionally starts with package name -> $1
+                  (?:\Q$info->{package}\E)?         # optionally starts with package name -> $1
                   (?: \s*+ \[([^\]]+?)\])?          # optionally followed by an [arch-list] (like in B-D) -> $2
                   (?:\s*+ ([a-z]+) \s*+ )?          # optionally followed by the type -> $3
                 :\s++)?                             # end optional part
@@ -547,7 +550,7 @@ sub file_overrides {
                    \Z/xsm
           ) {
             # Valid - so far at least
-            my ($opkg_name, $archlist, $opkg_type, $tagdata)= ($1, $2, $3, $4);
+            my ($archlist, $opkg_type, $tagdata)= ($1, $2, $3, $4);
             my ($rawtag, $extra) = split(m/ /o, $tagdata, 2);
             my $tag;
             my $tagover;
@@ -693,7 +696,7 @@ present.
 =cut
 
 sub load_overrides {
-    my ($self, $overrides) = @_;
+    my ($self) = @_;
     my $current = $self->{current};
     my $lpkg;
     my $overrides_file;
