@@ -270,7 +270,7 @@ sub _gen_type_coll {
 
     $cmap->initialise;
 
-    $self->{'cache'}->{$pkg_type} = $cmap;
+    $self->{'cache'}{$pkg_type} = $cmap;
     return $cmap->clone;
 }
 
@@ -281,10 +281,10 @@ sub _requested_colls {
     my $pkg_type = $lpkg->pkg_type;
     my ($cmap, %needed, @check);
 
-    unless (exists $self->{'cache'}->{$pkg_type}) {
+    unless (exists $self->{'cache'}{$pkg_type}) {
         $cmap = $self->_gen_type_coll($pkg_type);
     } else {
-        $cmap = $self->{'cache'}->{$pkg_type}->clone;
+        $cmap = $self->{'cache'}{$pkg_type}->clone;
     }
 
     # if its new and $profile is undef, we have to run all
@@ -333,7 +333,7 @@ HOOKS (if given) is a hashref of hooks.  The following hooks are available:
 
 Called each time a new collection job is started or finished.
 
-LPKG is the L<entry|Lintian::lab::Entry> it is applied to.  COLL is
+LPKG is the L<entry|Lintian::Lab::Entry> it is applied to.  COLL is
 the L<collection|Lintian::CollScript> being applied.  EVENT is either
 "start" for a new job or "finish" for a job terminating.
 
@@ -343,27 +343,6 @@ to signal a failure.
 STATUS is the exit status of the finishing job.  It is only available
 if EVENT is "finish" and if STATUS is non-zero is considered an error.
 
-=item finish-hook (LPKG, STATE[, CHANGED])
-
-Called once or twice for each entry processed at the end of the run.
-The LPKG is the L<entry|Lintian::Lab::Entry> being processed.
-
-For the first call, STATE is one of "changed" (the entry has been
-modified), "unchanged" (the entry was unmodified) or "failed" (at
-least one collection could not be applied).  Note that a "failed"
-entry may (or may not) be "changed" depending on where the failure
-happened.
-
-In the first call is done before the status file is written and the
-hook may alter the entry at this point (e.g. auto-remove unused
-collections).  If it does so CHANGED should be invoked as a code-ref
-to inform the unpacker of the change.
-
-The second call only happens for entries that has been changed (one
-way or another).  STATE will be one of "sf-success" or "sf-error",
-which determined on whether or not status file update was successful.
-On errors (i.e. "sf-error"), $! will contain the error.
-
 =back
 
 =cut
@@ -377,7 +356,6 @@ sub process_tasks {
 
     $hooks //= {};
     my $coll_hook = $hooks->{'coll-hook'};
-    my $finish_hook = $hooks->{'finish-hook'};
     my %failed;
     my %active = map { $_ => 1 } keys %$worklists;
 
@@ -442,11 +420,7 @@ sub process_tasks {
                         # For platforms that do not support, the child
                         # process will just keep its name as
                         # "lintian".
-
-#<<<
-                        # no Perltidy (breaks the no-critic)
-                        $0 = $coll;  ## no critic (Variables::RequireLocalizedPunctuationVars)
-#>>>
+                        $0 = "${coll} (processing ${procid})";
 
                         eval {$cs->collect($pkg_name, $pkg_type, $base);};
                         if ($@) {
@@ -454,6 +428,11 @@ sub process_tasks {
                             $ret = 2;
                         }
                     } else {
+                        if (my $coverage_arg = $ENV{'LINTIAN_COVERAGE'}) {
+                            my $p5opt = $ENV{'PERL5OPT'}//q{};
+                            $p5opt .= ' ' if $p5opt ne q{};
+                            $ENV{'PERL5OPT'} = "${p5opt} ${coverage_arg}";
+                        }
                         # Its fork + exec - invoke that directly (saves a fork)
                         exec $cs->script_path, $pkg_name, $pkg_type, $base
                           or die "exec $cs->script_path: $!";
@@ -513,7 +492,7 @@ sub process_tasks {
             foreach my $procid (keys %$worklists) {
                 # Failed ones do not count...
                 next if $failed{$procid};
-                my $cmap = $worklists->{$procid}->{'collmap'};
+                my $cmap = $worklists->{$procid}{'collmap'};
                 if ($cmap->pending) {
                     $done = 0;
                     last;
@@ -523,24 +502,6 @@ sub process_tasks {
         }
     }
 
-    foreach my $procid (keys %$worklists) {
-        my $wlist = $worklists->{$procid};
-        my $lpkg = $wlist->{'lab-entry'};
-        my $changed = $wlist->{'changed'};
-        my $state = 'unchanged';
-        $state = 'changed' if $changed;
-        $state = 'failed' if exists $failed{$procid};
-        $finish_hook->($lpkg, $state, sub { $changed = 1 })
-          if $finish_hook;
-        if ($changed) {
-            $state = 'sf-error';
-            if ($lpkg->update_status_file) {
-                $state = 'sf-success';
-            }
-            $finish_hook->($lpkg, $state)
-              if $finish_hook;
-        }
-    }
     return;
 }
 
